@@ -668,7 +668,7 @@ from datasae.quality.uniqueness import Uniqueness as Uniqueness
 from datasae.quality.comformity import Comformity as Comformity
 from datasae.quality.consistency import Consistency as Consistency
 from datasae.quality.timeliness import Timeliness as Timeliness
-from datasae.export.result import Result as Result
+from datasae.export_import.result import Result as Result
 from datasae.datasource.postgresql import ConnectionPostgres as ConnectionPostgres
-from datasae.export.rules import Rules as Rules
+from datasae.export_import.rules import Rules as Rules
 from datasae.core import quality as quality
